@@ -774,6 +774,8 @@ async def build_enums_from_config(db_config: DBConfig, include_strawberry: bool)
     enums_imports = build_enum_imports()
     enums_str = await build_enums(client, include_strawberry=include_strawberry)
     s = "\n".join([enums_imports, enums_str])
+    if s.strip().endswith(":"):
+        s += " pass"
     s = format_str(s, mode=FileMode())
     return s
 
