@@ -620,7 +620,10 @@ class Resolver(BaseModel, T.Generic[NodeType]):
         return cls._node.get_aliases()
 
     def parse_nested_obj(
-        self, raw_d: dict, error_for_extra_fields: bool = False
+        self,
+        raw_d: dict,
+        error_for_extra_fields: bool = False,
+        add_original_dict: bool = False,
     ) -> NodeType:
         if self.is_count and type(raw_d) is int:
             return raw_d
@@ -649,8 +652,10 @@ class Resolver(BaseModel, T.Generic[NodeType]):
             node.cache.add(
                 edge=edge_name, resolver=resolver, val=value_to_save, raw_d=raw_d
             )
-        node._used_resolver = self.copy(deep=True)
-        node._original_dict = raw_d.copy()
+        # node._used_resolver = self.copy(deep=True)
+        node._used_resolver = self
+        if add_original_dict:
+            node._original_dict = raw_d.copy()
         return node
 
     def merge(self) -> None:
